# arpes.plotting.visualize\_3d module

**arpes.plotting.visualize\_3d.plot\_isosurface(data, level=None,
percentile=99.5, smoothing=None, out=None, ax=None)**

**arpes.plotting.visualize\_3d.plot\_trisurf(data, out=None, ax=None,
angles=None)**

**arpes.plotting.visualize\_3d.plotly\_trisurf(data)**
